summaryrefslogtreecommitdiff
path: root/scheduler/client.h
diff options
context:
space:
mode:
authormsweet <msweet@a1ca3aef-8c08-0410-bb20-df032aa958be>2013-09-30 21:29:56 +0000
committermsweet <msweet@a1ca3aef-8c08-0410-bb20-df032aa958be>2013-09-30 21:29:56 +0000
commit996acce8760c538b9fee69c99f274ffc27744386 (patch)
tree20ddc829fe212839e8d498175df43f1d6a75152d /scheduler/client.h
parent5f8f4499daffc632431cd30e062dd8251980a67d (diff)
downloadcups-996acce8760c538b9fee69c99f274ffc27744386.tar.gz
Save work.
git-svn-id: svn+ssh://src.apple.com/svn/cups/cups.org/trunk@11321 a1ca3aef-8c08-0410-bb20-df032aa958be
Diffstat (limited to 'scheduler/client.h')
-rw-r--r--scheduler/client.h11
1 files changed, 7 insertions, 4 deletions
diff --git a/scheduler/client.h b/scheduler/client.h
index 87e4505be..b604d47a1 100644
--- a/scheduler/client.h
+++ b/scheduler/client.h
@@ -24,7 +24,8 @@
struct cupsd_client_s
{
- http_t http; /* HTTP client connection */
+ int number; /* Connection number */
+ http_t *http; /* HTTP client connection */
ipp_t *request, /* IPP request information */
*response; /* IPP response information */
cupsd_location_t *best; /* Best match for AAA */
@@ -53,7 +54,7 @@ struct cupsd_client_s
#ifdef HAVE_SSL
int auto_ssl; /* Automatic test for SSL/TLS */
#endif /* HAVE_SSL */
- http_addr_t clientaddr; /* Client address */
+ http_addr_t clientaddr; /* Client's server address */
char clientname[256];/* Client's server name for connection */
int clientport; /* Client's server port for connection */
char servername[256];/* Server name for connection */
@@ -67,7 +68,7 @@ struct cupsd_client_s
#endif /* HAVE_AUTHORIZATION_H */
};
-#define HTTP(con) &((con)->http)
+#define HTTP(con) ((con)->http)
/*
@@ -86,7 +87,9 @@ typedef struct
* Globals...
*/
-VAR int ListenBackLog VALUE(SOMAXCONN),
+VAR int LastClientNumber VALUE(0),
+ /* Last client connection number */
+ ListenBackLog VALUE(SOMAXCONN),
/* Max backlog of pending connections */
LocalPort VALUE(631),
/* Local port to use */